@@ -43,6 +43,9 @@
 #include <X11/Xlib.h>
 #include <fixx11h.h>
 #include <sys/resource.h>
+#if defined USE_POLICYKIT && USE_POLICYKIT==1
+#include "PolicyKitAuthenticator.h"
+#endif
 
 using namespace KDESu;
 
@@ -172,10 +175,12 @@ CJobRunner::CJobRunner(QWidget *parent, int xid)
              itsCancelClicked(false),
              itsModified(false)
 {
+#if !(defined USE_POLICYKIT && USE_POLICYKIT==1)
     // Set core dump size to 0 because we will have root's password in memory.
     struct rlimit rlim;
     rlim.rlim_cur=rlim.rlim_max=0;
     setrlimit(RLIMIT_CORE, &rlim);
+#endif
 
     setModal(true);
     setButtons(KDialog::Cancel);
@@ -203,6 +208,13 @@ bool CJobRunner::getAdminPasswd(QWidget *parent)
 {
     if(!Misc::root())
     {
+#if defined USE_POLICYKIT && USE_POLICYKIT==1
+        if(!PolicyKitAuthenticator::instance()->authenticate(KFI_IFACE, parent, true))
+        {
+            KMessageBox::error(parent, i18n("Authentication failed."));
+            return false;
+        }
+#else
         // Prompt the user for a password, if we do not already have it...
         if(itsPasswd.isEmpty() || 0!=SuProcess(KFI_SYS_USER).checkInstall(itsPasswd.toLocal8Bit()))
         {
@@ -212,6 +224,7 @@ bool CJobRunner::getAdminPasswd(QWidget *parent)
                 return false;
             itsPasswd=dlg.password().toLocal8Bit();
         }
+#endif
     }
 
     return true;
@@ -301,8 +314,8 @@ int CJobRunner::exec(ECommand cmd, const ItemList &urls, const KUrl &dest)
     itsUrls=urls;
     if(CMD_INSTALL==cmd)
         qSort(itsUrls.begin(), itsUrls.end());  // Sort list of fonts so that we have type1 fonts followed by their metrics...
-    itsIt=itsUrls.begin();
-    itsEnd=itsUrls.end();
+    itsIt=itsUrls.constBegin();
+    itsEnd=itsUrls.constEnd();
     itsProgress->setValue(0);
     itsProgress->setRange(0, itsUrls.count()+1);
     itsProgress->show();
@@ -338,7 +351,7 @@ void CJobRunner::doNext()
                 itsProgress->setValue(itsProgress->maximum());
 
             itsUrls.empty();
-            itsIt=itsEnd=itsUrls.end();
+            itsIt=itsEnd=itsUrls.constEnd();
 
             KIO::Job *job=KIO::special(KUrl(KFI_KIO_FONTS_PROTOCOL":/"), packedArgs, KIO::HideProgressInfo);
             setMetaData(job);
@@ -474,7 +487,7 @@ void CJobRunner::jobResult(KJob *job)
         else
         {
             itsUrls.empty();
-            itsIt=itsEnd=itsUrls.end();
+            itsIt=itsEnd=itsUrls.constEnd();
         }
         doNext();
     }
@@ -484,7 +497,7 @@ void CJobRunner::cfgResult(KJob *job)
 {
     stopAnimation();
 
-    // KIO::file_xxxx() dont seem to emit kdirnotify signals, so do this now...
+    // KIO::file_xxxx() do not seem to emit kdirnotify signals, so do this now...
     if(itsModified && (CMD_COPY==itsCmd || CMD_INSTALL==itsCmd))
         org::kde::KDirNotify::emitFilesAdded(itsDest.url());
 
@@ -521,11 +534,19 @@ KUrl CJobRunner::modifyUrl(const KUrl &orig) const
 {
     KUrl url(orig);
 
+#if defined USE_POLICYKIT && USE_POLICYKIT==1
+    if(!Misc::root())
+    {
+        url.setUser(KFI_SYS_USER);
+        url.setPass(QString().setNum(getpid()));
+    }
+#else
     if(!Misc::root() && !itsPasswd.isEmpty())
     {
         url.setUser(KFI_SYS_USER);
         url.setPass(itsPasswd);
     }
+#endif
 
     return url;
 }
@@ -551,7 +572,7 @@ CJobRunner::Item::Item(const KUrl &u, const QString &n)
 
 bool CJobRunner::Item::operator<(const Item &o) const
 {
-    // Dont care about the order of non type1 fonts/metrics...
+    // Do not care about the order of non type1 fonts/metrics...
     if(OTHER_FONT==type)
         return true;
 
