@@ -1,4 +1,5 @@
 /*
+ * Copyright 2008 Long Huynh Huu <long.upcase@googlemail.com>
  * Copyright 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
  * Copyright 2007 Casper Boemann <cbr@boemann.dk>
  * Copyright 2007 Fredrik Höglund <fredrik@kde.org>
@@ -38,7 +39,6 @@ public:
     explicit OxygenHelper(const QByteArray &componentName);
     virtual ~OxygenHelper() {}
 
-    void cleanupBeforeDelete() {OxygenHelper::invalidateCaches();}
     KSharedConfigPtr config() const;
     void reloadConfig();
 
@@ -66,7 +66,7 @@ public:
 
     QPixmap windecoButton(const QColor &color, bool pressed, int size = 21);
 
-    void drawFloatFrame(QPainter *p, const QRect r, const QColor &color) const;
+    void drawFloatFrame(QPainter *p, const QRect r, const QColor &color, bool drawUglyShadow=true, bool isActive=false, const QColor &frameColor=QColor()) const;
 
     void drawSeparator(QPainter *p, const QRect &r, const QColor &color, Qt::Orientation orientation) const;
 
