@@ -101,8 +101,8 @@ void Workspace::updateClientLayer( Client* c )
         return;
     StackingUpdatesBlocker blocker( this );
     c->invalidateLayer(); // invalidate, will be updated when doing restacking
-    for( ClientList::ConstIterator it = c->transients().begin();
-         it != c->transients().end();
+    for( ClientList::ConstIterator it = c->transients().constBegin();
+         it != c->transients().constEnd();
          ++it )
         updateClientLayer( *it );
     }
@@ -120,13 +120,13 @@ void Workspace::updateStackingOrder( bool propagate_new_clients )
     force_restacking = false;
     stacking_order = new_stacking_order;
 #if 0
-    kDebug() << "stacking:" << changed;
+    kDebug(1212) << "stacking:" << changed;
     if( changed || propagate_new_clients )
         {
         for( ClientList::ConstIterator it = stacking_order.begin();
              it != stacking_order.end();
              ++it )
-            kDebug() << (void*)(*it) << *it << ":" << (*it)->layer();
+            kDebug(1212) << (void*)(*it) << *it << ":" << (*it)->layer();
         }
 #endif
     if( changed || propagate_new_clients )
@@ -202,9 +202,9 @@ void Workspace::propagateClients( bool propagate_new_clients )
         cl = new Window[ desktops.count() + clients.count()];
         pos = 0;
 	// TODO this is still not completely in the map order
-        for ( ClientList::ConstIterator it = desktops.begin(); it != desktops.end(); ++it )
+        for ( ClientList::ConstIterator it = desktops.constBegin(); it != desktops.constEnd(); ++it )
             cl[pos++] =  (*it)->window();
-        for ( ClientList::ConstIterator it = clients.begin(); it != clients.end(); ++it )
+        for ( ClientList::ConstIterator it = clients.constBegin(); it != clients.constEnd(); ++it )
             cl[pos++] =  (*it)->window();
         rootInfo->setClientList( cl, pos );
         delete [] cl;
@@ -212,10 +212,14 @@ void Workspace::propagateClients( bool propagate_new_clients )
 
     cl = new Window[ stacking_order.count()];
     pos = 0;
-    for ( ClientList::ConstIterator it = stacking_order.begin(); it != stacking_order.end(); ++it)
+    for ( ClientList::ConstIterator it = stacking_order.constBegin(); it != stacking_order.constEnd(); ++it)
         cl[pos++] =  (*it)->window();
     rootInfo->setClientListStacking( cl, pos );
     delete [] cl;
+    
+    // Make the cached stacking order invalid here, in case we need the new stacking order before we get
+    // the matching event, due to X being asynchronous.
+    x_stacking_dirty = true; 
     }
 
 
@@ -224,8 +228,8 @@ void Workspace::propagateClients( bool propagate_new_clients )
   or of any other special kind are excluded. Also if the window
   doesn't accept focus it's excluded.
  */
-// TODO misleading name for this method
-Client* Workspace::topClientOnDesktop( int desktop, bool unconstrained, bool only_normal ) const
+// TODO misleading name for this method, too many slightly different ways to use it
+Client* Workspace::topClientOnDesktop( int desktop, int screen, bool unconstrained, bool only_normal ) const
     {
 // TODO    Q_ASSERT( block_stacking_updates == 0 );
     ClientList list;
@@ -239,6 +243,8 @@ Client* Workspace::topClientOnDesktop( int desktop, bool unconstrained, bool onl
         {
         if( list.at( i )->isOnDesktop( desktop ) && list.at( i )->isShown( false ))
             {
+            if( screen != -1 && list.at( i )->screen() != screen )
+                continue;
             if( !only_normal )
                 return list.at( i );
             if( list.at( i )->wantsTabFocus() && !list.at( i )->isSpecialWindow())
@@ -281,7 +287,8 @@ void Workspace::raiseOrLowerClient( Client *c)
          most_recently_raised->isShown( true ) && c->isOnCurrentDesktop())
         topmost = most_recently_raised;
     else
-        topmost = topClientOnDesktop( c->isOnAllDesktops() ? currentDesktop() : c->desktop());
+        topmost = topClientOnDesktop( c->isOnAllDesktops() ? currentDesktop() : c->desktop(),
+            options->separateScreenFocus ? c->screen() : -1 );
 
     if( c == topmost)
         lowerClient(c);
@@ -556,16 +563,16 @@ ClientList Workspace::constrainedStackingOrder()
     ClientList layer[ NumLayers ];
 
 #if 0
-    kDebug() << "stacking1:";
+    kDebug(1212) << "stacking1:";
     for( ClientList::ConstIterator it = unconstrained_stacking_order.begin();
          it != unconstrained_stacking_order.end();
          ++it )
-        kdDebug() << (void*)(*it) << *it << ":" << (*it)->layer();
+        kDebug(1212) << (void*)(*it) << *it << ":" << (*it)->layer();
 #endif
     // build the order from layers
     QHash< Group*, Layer > minimum_layer;
-    for( ClientList::ConstIterator it = unconstrained_stacking_order.begin();
-         it != unconstrained_stacking_order.end();
+    for( ClientList::ConstIterator it = unconstrained_stacking_order.constBegin();
+         it != unconstrained_stacking_order.constEnd();
          ++it )
         {
         Layer l = (*it)->layer();
@@ -587,11 +594,11 @@ ClientList Workspace::constrainedStackingOrder()
          ++lay )    
         stacking += layer[ lay ];
 #if 0
-    kDebug() << "stacking2:";
+    kDebug(1212) << "stacking2:";
     for( ClientList::ConstIterator it = stacking.begin();
          it != stacking.end();
          ++it )
-        kdDebug() << (void*)(*it) << *it << ":" << (*it)->layer();
+        kDebug(1212) << (void*)(*it) << *it << ":" << (*it)->layer();
 #endif
     // now keep transients above their mainwindows
     // TODO this could(?) use some optimization
@@ -655,12 +662,12 @@ ClientList Workspace::constrainedStackingOrder()
         stacking.insert( i2, current );
         }
 #if 0
-    kDebug() << "stacking3:";
+    kDebug(1212) << "stacking3:";
     for( ClientList::ConstIterator it = stacking.begin();
          it != stacking.end();
          ++it )
-        kdDebug() << (void*)(*it) << *it << ":" << (*it)->layer();
-    kDebug() << "\n\n";
+        kDebug(1212) << (void*)(*it) << *it << ":" << (*it)->layer();
+    kDebug(1212) << "\n\n";
 #endif
     return stacking;
     }
@@ -686,8 +693,8 @@ ClientList Workspace::ensureStackingOrder( const ClientList& list ) const
         return list;
     // TODO is this worth optimizing?
     ClientList result = list;
-    for( ClientList::ConstIterator it = stacking_order.begin();
-         it != stacking_order.end();
+    for( ClientList::ConstIterator it = stacking_order.constBegin();
+         it != stacking_order.constEnd();
          ++it )
         if( result.removeAll( *it ) != 0 )
             result.append( *it );
@@ -720,30 +727,33 @@ bool Workspace::keepTransientAbove( const Client* mainwindow, const Client* tran
     return true;
     }
 
-// Returns all windows in their stacking order on the root window, used only by compositing.
-// TODO This possibly should be optimized to avoid the X roundtrip and building it every pass.
-ToplevelList Workspace::compositingStackingOrder() const
+// Returns all windows in their stacking order on the root window.
+ToplevelList Workspace::xStackingOrder() const
     {
+    if( !x_stacking_dirty )
+        return x_stacking;
+    x_stacking_dirty = false;
+    x_stacking.clear();
     Window dummy;
     Window* windows = NULL;
     unsigned int count = 0;
     XQueryTree( display(), rootWindow(), &dummy, &dummy, &windows, &count );
-    ToplevelList ret;
     // use our own stacking order, not the X one, as they may differ
     foreach( Client* c, stacking_order )
-        ret.append( c );
+        x_stacking.append( c );
     for( unsigned int i = 0;
          i < count;
          ++i )
         {
         if( Unmanaged* c = findUnmanaged( WindowMatchPredicate( windows[ i ] )))
-            ret.append( c );
+            x_stacking.append( c );
         }
     foreach( Deleted* c, deleted )
-        ret.append( c );
+        x_stacking.append( c );
     if( windows != NULL )
         XFree( windows );
-    return ret;
+    const_cast< Workspace* >( this )->checkUnredirect();
+    return x_stacking;
     }
 
 //*******************************
@@ -832,17 +842,22 @@ Layer Client::belongsToLayer() const
         return DockLayer;
     if( isTopMenu())
         return DockLayer;
-    // only raise fullscreen above docks if it's the topmost window in unconstrained stacking order,
-    // i.e. the window set to be topmost by the user (also includes transients of the fullscreen window)
-    const Client* ac = workspace()->mostRecentlyActivatedClient(); // instead of activeClient() - avoids flicker
-    const Client* top = workspace()->topClientOnDesktop( desktop(), true, false );
-    if( isFullScreen() && ac != NULL && top != NULL
-        && ( ac == this || this->group() == ac->group())
-        && ( top == this || this->group() == top->group()))
+    if( isActiveFullScreen())
         return ActiveLayer;
     if( keepAbove())
         return AboveLayer;
     return NormalLayer;
     }
 
+bool Client::isActiveFullScreen() const
+    {
+    // only raise fullscreen above docks if it's the topmost window in unconstrained stacking order,
+    // i.e. the window set to be topmost by the user (also includes transients of the fullscreen window)
+    const Client* ac = workspace()->mostRecentlyActivatedClient(); // instead of activeClient() - avoids flicker
+    const Client* top = workspace()->topClientOnDesktop( workspace()->currentDesktop(), screen(), true, false );
+    return( isFullScreen() && ac != NULL && top != NULL
+// not needed, for xinerama  && ( ac == this || this->group() == ac->group())
+        && ( top == this || this->group() == top->group()));
+    }
+
 } // namespace
