@@ -37,7 +37,8 @@
 #include <kapplication.h>
 #include "kdecorationfactory.h"
 #include <klocale.h>
-#include <QDesktopWidget>
+
+#include <kephal/screens.h>
 
 #include "kcommondecoration.moc"
 
@@ -343,116 +344,116 @@ void KCommonDecoration::addButtons(ButtonContainer &btnContainer, const QString&
         for (int n=0; n < s.length(); n++) {
             KCommonDecorationButton *btn = 0;
             switch (s[n].toAscii()) {
-              case 'M': // Menu button
-                  if (!m_button[MenuButton]){
-                      btn = createButton(MenuButton);
-                      if (!btn) break;
-                      btn->setTipText(i18n("Menu") );
-                      btn->setRealizeButtons(Qt::LeftButton|Qt::RightButton);
-                      connect(btn, SIGNAL(pressed()), SLOT(menuButtonPressed()));
-                      connect(btn, SIGNAL(released()), this, SLOT(menuButtonReleased()));
+                case 'M': // Menu button
+                    if (!m_button[MenuButton]){
+                        btn = createButton(MenuButton);
+                        if (!btn) break;
+                        btn->setTipText(i18n("Menu") );
+                        btn->setRealizeButtons(Qt::LeftButton|Qt::RightButton);
+                        connect(btn, SIGNAL(pressed()), SLOT(menuButtonPressed()));
+                        connect(btn, SIGNAL(released()), this, SLOT(menuButtonReleased()));
 
-                      m_button[MenuButton] = btn;
-                  }
-                  break;
-              case 'S': // OnAllDesktops button
-                  if (!m_button[OnAllDesktopsButton]){
-                      btn = createButton(OnAllDesktopsButton);
-                      if (!btn) break;
-                      const bool oad = isOnAllDesktops();
-                      btn->setTipText(oad?i18n("Not on all desktops"):i18n("On all desktops") );
-                      btn->setToggleButton(true);
-                      btn->setOn( oad );
-                      connect(btn, SIGNAL(clicked()), SLOT(toggleOnAllDesktops()));
+                        m_button[MenuButton] = btn;
+                    }
+                    break;
+                case 'S': // OnAllDesktops button
+                    if (!m_button[OnAllDesktopsButton]){
+                        btn = createButton(OnAllDesktopsButton);
+                        if (!btn) break;
+                        const bool oad = isOnAllDesktops();
+                        btn->setTipText(oad?i18n("Not on all desktops"):i18n("On all desktops") );
+                        btn->setToggleButton(true);
+                        btn->setOn( oad );
+                        connect(btn, SIGNAL(clicked()), SLOT(toggleOnAllDesktops()));
 
-                      m_button[OnAllDesktopsButton] = btn;
-                  }
-                  break;
-              case 'H': // Help button
-                  if ((!m_button[HelpButton]) && providesContextHelp()){
-                      btn = createButton(HelpButton);
-                      if (!btn) break;
-                      btn->setTipText(i18n("Help") );
-                      connect(btn, SIGNAL(clicked()), SLOT(showContextHelp()));
+                        m_button[OnAllDesktopsButton] = btn;
+                    }
+                    break;
+                case 'H': // Help button
+                    if ((!m_button[HelpButton]) && providesContextHelp()){
+                        btn = createButton(HelpButton);
+                        if (!btn) break;
+                        btn->setTipText(i18n("Help") );
+                        connect(btn, SIGNAL(clicked()), SLOT(showContextHelp()));
 
-                      m_button[HelpButton] = btn;
-                  }
-                  break;
-              case 'I': // Minimize button
-                  if ((!m_button[MinButton]) && isMinimizable()){
-                      btn = createButton(MinButton);
-                      if (!btn) break;
-                      btn->setTipText(i18n("Minimize") );
-                      connect(btn, SIGNAL(clicked()), SLOT(minimize()));
+                        m_button[HelpButton] = btn;
+                    }
+                    break;
+                case 'I': // Minimize button
+                    if ((!m_button[MinButton]) && isMinimizable()){
+                        btn = createButton(MinButton);
+                        if (!btn) break;
+                        btn->setTipText(i18n("Minimize") );
+                        connect(btn, SIGNAL(clicked()), SLOT(minimize()));
 
-                      m_button[MinButton] = btn;
-                  }
-                  break;
-              case 'A': // Maximize button
-                  if ((!m_button[MaxButton]) && isMaximizable()){
-                      btn = createButton(MaxButton);
-                      if (!btn) break;
-                      btn->setRealizeButtons(Qt::LeftButton|Qt::MidButton|Qt::RightButton);
-                      const bool max = maximizeMode()==MaximizeFull;
-                      btn->setTipText(max?i18n("Restore"):i18n("Maximize") );
-                      btn->setToggleButton(true);
-                      btn->setOn( max );
-                      connect(btn, SIGNAL(clicked()), SLOT(slotMaximize()));
+                        m_button[MinButton] = btn;
+                    }
+                    break;
+                case 'A': // Maximize button
+                    if ((!m_button[MaxButton]) && isMaximizable()){
+                        btn = createButton(MaxButton);
+                        if (!btn) break;
+                        btn->setRealizeButtons(Qt::LeftButton|Qt::MidButton|Qt::RightButton);
+                        const bool max = maximizeMode()==MaximizeFull;
+                        btn->setTipText(max?i18n("Restore"):i18n("Maximize") );
+                        btn->setToggleButton(true);
+                        btn->setOn( max );
+                        connect(btn, SIGNAL(clicked()), SLOT(slotMaximize()));
 
-                      m_button[MaxButton] = btn;
-                  }
-                  break;
-              case 'X': // Close button
-                  if ((!m_button[CloseButton]) && isCloseable()){
-                      btn = createButton(CloseButton);
-                      if (!btn) break;
-                      btn->setTipText(i18n("Close") );
-                      connect(btn, SIGNAL(clicked()), SLOT(closeWindow()));
+                        m_button[MaxButton] = btn;
+                    }
+                    break;
+                case 'X': // Close button
+                    if ((!m_button[CloseButton]) && isCloseable()){
+                        btn = createButton(CloseButton);
+                        if (!btn) break;
+                        btn->setTipText(i18n("Close") );
+                        connect(btn, SIGNAL(clicked()), SLOT(closeWindow()));
 
-                      m_button[CloseButton] = btn;
-                  }
-                  break;
-              case 'F': // AboveButton button
-                  if (!m_button[AboveButton]){
-                      btn = createButton(AboveButton);
-                      if (!btn) break;
-                      bool above = keepAbove();
-                      btn->setTipText(above?i18n("Do not keep above others"):i18n("Keep above others") );
-                      btn->setToggleButton(true);
-                      btn->setOn( above );
-                      connect(btn, SIGNAL(clicked()), SLOT(slotKeepAbove()));
+                        m_button[CloseButton] = btn;
+                    }
+                    break;
+                case 'F': // AboveButton button
+                    if (!m_button[AboveButton]){
+                        btn = createButton(AboveButton);
+                        if (!btn) break;
+                        bool above = keepAbove();
+                        btn->setTipText(above?i18n("Do not keep above others"):i18n("Keep above others") );
+                        btn->setToggleButton(true);
+                        btn->setOn( above );
+                        connect(btn, SIGNAL(clicked()), SLOT(slotKeepAbove()));
 
-                      m_button[AboveButton] = btn;
-                  }
-                  break;
-              case 'B': // BelowButton button
-                  if (!m_button[BelowButton]){
-                      btn = createButton(BelowButton);
-                      if (!btn) break;
-                      bool below = keepBelow();
-                      btn->setTipText(below?i18n("Do not keep below others"):i18n("Keep below others") );
-                      btn->setToggleButton(true);
-                      btn->setOn( below );
-                      connect(btn, SIGNAL(clicked()), SLOT(slotKeepBelow()));
+                        m_button[AboveButton] = btn;
+                    }
+                    break;
+                case 'B': // BelowButton button
+                    if (!m_button[BelowButton]){
+                        btn = createButton(BelowButton);
+                        if (!btn) break;
+                        bool below = keepBelow();
+                        btn->setTipText(below?i18n("Do not keep below others"):i18n("Keep below others") );
+                        btn->setToggleButton(true);
+                        btn->setOn( below );
+                        connect(btn, SIGNAL(clicked()), SLOT(slotKeepBelow()));
 
-                      m_button[BelowButton] = btn;
-                  }
-                  break;
-              case 'L': // Shade button
-                  if ((!m_button[ShadeButton]) && isShadeable()){
-                      btn = createButton(ShadeButton);
-                      if (!btn) break;
-                      bool shaded = isSetShade();
-                      btn->setTipText(shaded?i18n("Unshade"):i18n("Shade") );
-                      btn->setToggleButton(true);
-                      btn->setOn( shaded );
-                      connect(btn, SIGNAL(clicked()), SLOT(slotShade()));
+                        m_button[BelowButton] = btn;
+                    }
+                    break;
+                case 'L': // Shade button
+                    if ((!m_button[ShadeButton]) && isShadeable()){
+                        btn = createButton(ShadeButton);
+                        if (!btn) break;
+                        bool shaded = isSetShade();
+                        btn->setTipText(shaded?i18n("Unshade"):i18n("Shade") );
+                        btn->setToggleButton(true);
+                        btn->setOn( shaded );
+                        connect(btn, SIGNAL(clicked()), SLOT(slotShade()));
 
-                      m_button[ShadeButton] = btn;
-                  }
-                  break;
-              case '_': // Spacer item
-                  btnContainer.append(0);
+                        m_button[ShadeButton] = btn;
+                    }
+                    break;
+                case '_': // Spacer item
+                    btnContainer.append(0);
             }
 
 
@@ -799,11 +800,10 @@ void KCommonDecoration::updateWindowShape()
 
     bool tl=true,tr=true,bl=true,br=true; // is there a transparent rounded corner in top-left? etc
 
-    QDesktopWidget *desktop=KApplication::desktop();
     // no transparent rounded corners if this window corner lines up with a screen corner
-    for(int screen=0; screen < desktop->numScreens(); ++screen)
+    for(int screen=0; screen < Kephal::ScreenUtils::numScreens(); ++screen)
     {
-        QRect fullscreen(desktop->screenGeometry(screen));
+        QRect fullscreen(Kephal::ScreenUtils::screenGeometry(screen));
         QRect window = geometry();
 
         if(window.topLeft()    == fullscreen.topLeft() ) tl = false;
@@ -1221,5 +1221,58 @@ KDecoration* KCommonDecoration::decoration()
     return wrapper;
 }
 
+
+KCommonDecorationUnstable::KCommonDecorationUnstable(KDecorationBridge* bridge, KDecorationFactory* factory)
+    : KCommonDecoration( bridge, factory )
+    {
+    Q_ASSERT( dynamic_cast<const KDecorationUnstable*>( decoration() ));
+    }
+
+KCommonDecorationUnstable::~KCommonDecorationUnstable()
+    {
+    }
+
+// All copied from kdecoration.cpp
+QList<QRect> KCommonDecorationUnstable::shadowQuads( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return QList<QRect>();
+    }
+double KCommonDecorationUnstable::shadowOpacity( ShadowType type ) const
+    {
+    if( isActive() && type == ShadowBorderedActive )
+        return 1.0;
+    else if( !isActive() && type == ShadowBorderedInactive )
+        return 1.0;
+    return 0.0;
+    }
+double KCommonDecorationUnstable::shadowBrightness( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return 1.0;
+    }
+double KCommonDecorationUnstable::shadowSaturation( ShadowType type ) const
+    {
+    Q_UNUSED( type );
+    return 1.0;
+    }
+
+void KCommonDecorationUnstable::repaintShadow()
+    {
+    return static_cast<const KDecorationUnstable*>( decoration() )->repaintShadow();
+    }
+bool KCommonDecorationUnstable::compositingActive() const
+    {
+    return static_cast<const KDecorationUnstable*>( decoration() )->compositingActive();
+    }
+bool KCommonDecorationUnstable::shadowsActive() const
+    {
+    return static_cast<const KDecorationUnstable*>( decoration() )->shadowsActive();
+    }
+double KCommonDecorationUnstable::opacity() const
+    {
+    return static_cast<const KDecorationUnstable*>( decoration() )->opacity();
+    }
+
 // kate: space-indent on; indent-width 4; mixedindent off; indent-mode cstyle;
 
