@@ -32,6 +32,8 @@
 #include <QIcon>
 #include <QPixmap>
 #include <QList>
+#include <QMimeData>
+#include <QTextDocument>
 
 #define HEADING_X_ICON_SIZE 16
 
@@ -178,7 +180,7 @@ void ProcessModelPrivate::windowChanged(WId wid, unsigned int properties)
 
 void ProcessModelPrivate::windowAdded(WId wid)
 {
-	foreach(WindowInfo w, mPidToWindowInfo.values()) {
+	foreach(WindowInfo w, mPidToWindowInfo) {
 		if(w.wid == wid) return; //already added
 	}
 	//The name changed
@@ -637,20 +639,21 @@ bool ProcessModel::canUserLogin(long long uid ) const
 
 QString ProcessModelPrivate::getTooltipForUser(const KSysGuard::Process *ps) const
 {
-	QString userTooltip;
+	QString userTooltip = "<qt><p style='white-space:pre'>";
 	if(!mIsLocalhost) {
-		userTooltip = "<qt>";
 		userTooltip += i18n("Login Name: %1<br/>", getUsernameForUser(ps->uid, true));
 	} else {
 		KUser user(ps->uid);
 		if(!user.isValid())
-			userTooltip = i18n("This user is not recognized for some reason.");
+			userTooltip += i18n("This user is not recognized for some reason.");
 		else {
-			userTooltip = "<qt>";
-            if(!user.property(KUser::FullName).isValid()) userTooltip += i18n("<b>%1</b><br/>", user.property(KUser::FullName).toString());
+			if(!user.property(KUser::FullName).isValid()) 
+				userTooltip += i18n("<b>%1</b><br/>", user.property(KUser::FullName).toString());
 			userTooltip += i18n("Login Name: %1 (uid: %2)<br/>", user.loginName(), ps->uid);
-            if(!user.property(KUser::RoomNumber).isValid()) userTooltip += i18n("  Room Number: %1<br/>", user.property(KUser::RoomNumber).toString());
-            if(!user.property(KUser::WorkPhone).isValid()) userTooltip += i18n("  Work Phone: %1<br/>", user.property(KUser::WorkPhone).toString());
+			if(!user.property(KUser::RoomNumber).isValid()) 
+				userTooltip += i18n("  Room Number: %1<br/>", user.property(KUser::RoomNumber).toString());
+			if(!user.property(KUser::WorkPhone).isValid()) 
+				userTooltip += i18n("  Work Phone: %1<br/>", user.property(KUser::WorkPhone).toString());
 		}
 	}
 	if( (ps->uid != ps->euid && ps->euid != -1) || 
@@ -811,9 +814,9 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 		}
 		switch(index.column()) {
 		case HeadingName: {
-			QString tooltip = "<qt>";
-			/***  It would be nice to be able to show the icon in the tooltip, but Qt4 won't let us put
-			 *    a picture in a tooltip :(
+			QString tooltip = "<qt><p style='white-space:pre'>";
+			/*   It would be nice to be able to show the icon in the tooltip, but Qt4 won't let us put
+			 *   a picture in a tooltip :(
 			   
 			QIcon icon;
 			if(mPidToWindowInfo.contains(process->pid)) {
@@ -866,15 +869,15 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 			return d->getTooltipForUser(process);
 		}
 		case HeadingNiceness: {
-		        QString tooltip;
+		        QString tooltip = "<qt><p style='white-space:pre'>";
 			switch(process->scheduler) {
 			  case KSysGuard::Process::Other:
 			  case KSysGuard::Process::Batch:
-				  tooltip = i18n("<qt>Nice level: %1 (%2)", process->niceLevel, process->niceLevelAsString() );
+				  tooltip += i18n("Nice level: %1 (%2)", process->niceLevel, process->niceLevelAsString() );
 				  break;
 			  case KSysGuard::Process::RoundRobin:
 			  case KSysGuard::Process::Fifo:
-				  tooltip = i18n("<qt>Scheduler priority: %1", process->niceLevel);
+				  tooltip += i18n("Scheduler priority: %1", process->niceLevel);
 				  break;
 			}
 			if(process->scheduler != KSysGuard::Process::Other)
@@ -889,7 +892,8 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 			return tooltip + "<br />" + tracer;
 		}	
 		case HeadingCPUUsage: {
-			QString tooltip = ki18n("<qt>Process status: %1 %2<br />"
+			QString tooltip = ki18n("<qt><p style='white-space:pre'>"
+						"Process status: %1 %2<br />"
 						"User CPU usage: %3%<br />System CPU usage: %4%</qt>")
 						.subs(process->translatedStatus())
 						.subs(d->getStatusDescription(process->status))
@@ -930,7 +934,7 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 			return QVariant();
 		}
 		case HeadingMemory: {
-			QString tooltip = "<qt>";
+			QString tooltip = "<qt><p style='white-space:pre'>";
 			if(process->vmURSS != -1) {
 				//We don't have information about the URSS, so just fallback to RSS
 				if(d->mMemTotal > 0)
@@ -945,9 +949,11 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 			return tooltip;
 		}
 		case HeadingSharedMemory: {
-			if(process->vmURSS == -1)
-				return i18n("<qt>Your system does not seem to have this information available to be read.</qt>");
-			QString tooltip = "<qt>";
+			QString tooltip = "<qt><p style='white-space:pre'>";
+			if(process->vmURSS == -1) {
+				tooltip += i18n("<qt>Your system does not seem to have this information available to be read.</qt>");
+				return tooltip;
+			}
 			if(d->mMemTotal >0)
 				tooltip += i18n("Shared library memory usage: %1 out of %2  (%3 %)", KGlobal::locale()->formatByteSize((process->vmRSS - process->vmURSS) * 1024), KGlobal::locale()->formatByteSize(d->mMemTotal*1024), (process->vmRSS-process->vmURSS)*100/d->mMemTotal);
 			else
@@ -973,7 +979,7 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 				}
 			}
 			if(!tooltip.isEmpty())
-				return "<qt><ul>" + tooltip + "</ul>";
+				return "<qt><p style='white-space:pre'><ul>" + tooltip + "</ul>";
 			return QVariant(QVariant::String);
 		}
 
@@ -1063,6 +1069,66 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 		}
 		return QVariant();
 	}
+	case PlainValueRole:  //Used to return a plain value.  For copying to a clipboard etc
+	{
+		KSysGuard::Process *process = reinterpret_cast< KSysGuard::Process * > (index.internalPointer());
+		switch(index.column()) {
+		case HeadingName:
+			return process->name;
+		case HeadingPid:
+			return (qlonglong)process->pid;
+		case HeadingUser:
+			if(!process->login.isEmpty()) return process->login;
+			if(process->uid == process->euid)
+				return d->getUsernameForUser(process->uid, false);
+			else
+				return d->getUsernameForUser(process->uid, false) + ", " + d->getUsernameForUser(process->euid, false);
+		case HeadingNiceness:
+			return process->niceLevel;
+		case HeadingTty:
+			return process->tty;
+		case HeadingCPUUsage:
+			{
+				double total;
+				if(d->mShowChildTotals && !d->mSimple) total = process->totalUserUsage + process->totalSysUsage;
+				else total = process->userUsage + process->sysUsage;
+				return total / d->mNumProcessorCores;
+			}
+		case HeadingMemory:
+			if(process->vmRSS == 0) return QVariant(QVariant::String);
+			if(process->vmURSS == -1) {
+				return (long long)process->vmRSS;
+			} else {
+				return (long long)process->vmURSS;
+			}
+		case HeadingVmSize:
+			return (long long)process->vmSize;
+		case HeadingSharedMemory:
+			if(process->vmRSS - process->vmURSS < 0 || process->vmURSS == -1) return QVariant(QVariant::String);
+			return (long long)(process->vmRSS - process->vmURSS);
+		case HeadingCommand: 
+			{
+				return process->command;
+			}
+#ifdef Q_WS_X11
+		case HeadingXTitle:
+			{
+				if(!d->mPidToWindowInfo.contains(process->pid)) return QVariant(QVariant::String);
+				WindowInfo w = d->mPidToWindowInfo.value(process->pid);
+				if(!w.netWinInfo) return QVariant(QVariant::String);
+				const char *name = w.netWinInfo->visibleName();
+				if( !name || name[0] == 0 )
+					name = w.netWinInfo->name();
+				if(name && name[0] != 0)
+					return QString::fromUtf8(name);
+				return QVariant(QVariant::String);
+			}
+#endif
+		default:
+			return QVariant();
+		}
+		break;
+	}
 #ifdef Q_WS_X11
         case WindowIdRole: {
 		KSysGuard::Process *process = reinterpret_cast< KSysGuard::Process * > (index.internalPointer());
@@ -1095,9 +1161,9 @@ QVariant ProcessModel::data(const QModelIndex &index, int role) const
 		} else if (index.column() == HeadingCPUUsage) {
 			KSysGuard::Process *process = reinterpret_cast< KSysGuard::Process * > (index.internalPointer());
 			if(process->status == KSysGuard::Process::Stopped || process->status == KSysGuard::Process::Zombie) {
-        			QPixmap pix = KIconLoader::global()->loadIcon("button_cancel", KIconLoader::Small,
-			                KIconLoader::SizeSmall, KIconLoader::DefaultState, QStringList(),
-				        0L, true);
+        	//		QPixmap pix = KIconLoader::global()->loadIcon("button_cancel", KIconLoader::Small,
+		//	                KIconLoader::SizeSmall, KIconLoader::DefaultState, QStringList(),
+		//		        0L, true);
 
 			}
 		}
@@ -1238,4 +1304,81 @@ QString ProcessModel::formatMemoryInfo(long amountInKB) const
 QString ProcessModel::hostName() const {
 	return d->mHostName;
 }
+QStringList ProcessModel::mimeTypes() const
+{
+	QStringList types;
+	types << "text/plain";
+	types << "text/csv";
+	types << "text/html";
+	return types;
+}
+QMimeData *ProcessModel::mimeData(const QModelIndexList &indexes) const
+{
+	QMimeData *mimeData = new QMimeData();
+	QString textCsv;
+	QString textCsvHeaders;
+	QString textPlain;
+	QString textPlainHeaders;
+	QString textHtml;
+	QString textHtmlHeaders;
+	QString display;
+	int firstColumn = -1;
+	bool firstrow = true;
+	foreach (QModelIndex index, indexes) {
+		if (index.isValid()) {
+			if(firstColumn == -1)
+				firstColumn = index.column();
+			else if(firstColumn != index.column())
+				continue;
+			else {
+				textCsv += '\n';
+				textPlain += '\n';
+				textHtml += "</tr><tr>";
+				firstrow = false;
+			}
+			for(int i = 0; i < d->mHeadings.size(); i++) {
+				if(firstrow) {
+					QString heading = d->mHeadings[i];
+					textHtmlHeaders += "<th>" + heading + "</th>";
+					if(i) {
+						textCsvHeaders += ',';
+						textPlainHeaders += ", ";
+					}
+					textPlainHeaders += heading;
+					heading.replace('"', "\"\"");
+					textCsvHeaders += '"' + heading + '"';
+				}
+				QModelIndex index2 = createIndex(index.row(), i, reinterpret_cast< KSysGuard::Process * > (index.internalPointer()));
+				QString display = data(index2, PlainValueRole).toString();
+				if(i) {
+					textCsv += ',';
+					textPlain += ", ";
+				}
+				textHtml += "<td>" + Qt::escape(display) + "</td>";
+				textPlain += display;
+				display.replace('"',"\"\"");
+				textCsv += '"' + display + '"';
+			}
+		}
+	}
+	textHtml = "<html><table><tr>" + textHtmlHeaders + "</tr><tr>" + textHtml + "</tr></table>";
+	textCsv = textCsvHeaders + '\n' + textCsv;
+	textPlain = textPlainHeaders + '\n' + textPlain;
+
+	mimeData->setText(textPlain);
+	mimeData->setHtml(textHtml);
+	mimeData->setData("text/csv", textCsv.toUtf8());
+	return mimeData;
+
+}
+Qt::ItemFlags ProcessModel::flags(const QModelIndex &index) const
+{
+	Qt::ItemFlags defaultFlags = QAbstractItemModel::flags(index);
+	if (index.isValid())
+		return Qt::ItemIsDragEnabled | defaultFlags;
+	else
+		return defaultFlags;
+
+}
+
 
