@@ -152,6 +152,9 @@ public:
                 action->setVisible(action->menu() || ! view->indexForAction(action).data(Kickoff::UrlRole).isNull());
                 menuview->addAction(action);
             }
+            if (! action->menu()) {
+                view->removeAction(action);
+            }
         }
 
         // if the model asks us for a reset we can't do much except to invalidate our
@@ -373,12 +376,14 @@ void MenuLauncherApplet::toggleMenu()
         d->menuview = new Kickoff::MenuView();
         connect(d->menuview, SIGNAL(triggered(QAction*)), this, SLOT(actionTriggered(QAction*)));
         connect(d->menuview, SIGNAL(aboutToHide()), d->icon, SLOT(setUnpressed()));
-        connect(d->menuview, SIGNAL(aboutToHide()), d->menuview, SLOT(deleteLater()));
+        connect(d->menuview, SIGNAL(afterBeingHidden()), d->menuview, SLOT(deleteLater()));
 
         switch (d->viewtype) {
         case Combined: {
             Kickoff::ApplicationModel *appModel = new Kickoff::ApplicationModel(d->menuview);
             appModel->setDuplicatePolicy(Kickoff::ApplicationModel::ShowLatestOnlyPolicy);
+            if (d->formattype == Name || d->formattype == NameDescription || d->formattype == NameDashDescription)
+                appModel->setPrimaryNamePolicy(Kickoff::ApplicationModel::AppNamePrimary);
             appModel->setSystemApplicationPolicy(Kickoff::ApplicationModel::ShowApplicationAndSystemPolicy);
             Kickoff::MenuView *appview = d->createMenuView(appModel);
             d->addMenu(appview, false);
@@ -404,6 +409,8 @@ void MenuLauncherApplet::toggleMenu()
         case Applications: {
             Kickoff::ApplicationModel *appModel = new Kickoff::ApplicationModel(d->menuview);
             appModel->setDuplicatePolicy(Kickoff::ApplicationModel::ShowLatestOnlyPolicy);
+            if (d->formattype == Name || d->formattype == NameDescription || d->formattype == NameDashDescription)
+                appModel->setPrimaryNamePolicy(Kickoff::ApplicationModel::AppNamePrimary);
             Kickoff::MenuView *appview = d->createMenuView(appModel);
             d->addMenu(appview, false);
         }
