@@ -13,6 +13,20 @@
 
 #include "itemspace.h"
 
+// Contrary to QRectF::intersects(), this function requires the
+// rectangles to truly intersect, not just touch on one side.
+// Further, we require a minimal overlap distance to prevent
+// an infinite loop in the positioning algorithm due to some
+// precision and optimization problems.
+bool __intersects (const QRectF &a, const QRectF &b)
+{
+    if (!(a.bottom() - 0.001 > b.top())) return false;
+    if (!(a.top() + 0.001 < b.bottom())) return false;
+    if (!(a.right() - 0.001 > b.left())) return false;
+    if (!(a.left() + 0.001 < b.right())) return false;
+    return true;
+}
+
 ItemSpace::ItemSpace()
   : spaceAlignment(Qt::AlignTop|Qt::AlignLeft),
     workingGeom(QSizeF()),
@@ -184,7 +198,7 @@ QList<QPointF> ItemSpace::positionVertically(
     // start either on the left or the right, and advance inside
     qreal x = ((align & Qt::AlignLeft) ? 0 : workingGeom.width()-size.width());
     // try different x coordinates
-    for (int i = 0; i < 100; ++i) {
+    while (1) {
         // stop testing if we're limited by the working area and positions at the next x would reach outside
         bool outOfX = ((align & Qt::AlignLeft) ? (x + size.width() > workingGeom.width()) : (x < 0));
         if (outOfX && limitedSpace) {
@@ -229,9 +243,11 @@ QList<QPointF> ItemSpace::positionVertically(
                 break;
             }
 
-            Q_ASSERT( ((align & Qt::AlignTop) && a.bottom() > y) || ((align & Qt::AlignBottom) && a.y() - size.height() < y) );
-
-            y = ((align & Qt::AlignTop) ? a.bottom() : a.y() - size.height());
+            if ((align & Qt::AlignTop)) {
+                y = a.bottom();
+            } else {
+                y = a.y() - size.height();
+            }
         }
 
         // Find next possible x coordinate
@@ -255,9 +271,11 @@ QList<QPointF> ItemSpace::positionVertically(
             break;
         }
 
-        Q_ASSERT( ((align & Qt::AlignLeft) && a.right() > x) || ((align & Qt::AlignRight) && a.x() - size.width() < x) );
-
-        x = ((align & Qt::AlignLeft) ? a.right() : a.x() - size.width());
+        if ((align & Qt::AlignLeft)) {
+            x = a.right();
+        } else {
+            x = a.x() - size.width();
+        }
     }
 
     return possiblePositions;
@@ -278,7 +296,7 @@ QRectF ItemSpace::itemInRegionStartingFirstVert(const QRectF &region) const
               continue;
             }
             qreal cl = item.lastGeometry.y();
-            if (item.lastGeometry.intersects(region) && cl < l) {
+            if (__intersects(item.lastGeometry, region) && cl < l) {
                 ret = item.lastGeometry;
                 l = cl;
             }
@@ -302,7 +320,7 @@ QRectF ItemSpace::itemInRegionEndingLastVert(const QRectF &region) const
               continue;
             }
             qreal cl = item.lastGeometry.y() + item.lastGeometry.height();
-            if (item.lastGeometry.intersects(region) && cl > l) {
+            if (__intersects(item.lastGeometry, region) && cl > l) {
                 ret = item.lastGeometry;
                 l = cl;
             }
@@ -326,7 +344,7 @@ QRectF ItemSpace::itemInRegionEndingFirstHoriz(const QRectF &region) const
               continue;
             }
             qreal cl = item.lastGeometry.x() + item.lastGeometry.width();
-            if (item.lastGeometry.intersects(region) && cl < l) {
+            if (__intersects(item.lastGeometry, region) && cl < l) {
                 ret = item.lastGeometry;
                 l = cl;
             }
@@ -350,7 +368,7 @@ QRectF ItemSpace::itemInRegionStartingLastHoriz(const QRectF &region) const
               continue;
             }
             qreal cl = item.lastGeometry.x();
-            if (item.lastGeometry.intersects(region) && cl > l) {
+            if (__intersects(item.lastGeometry, region) && cl > l) {
                 ret = item.lastGeometry;
                 l = cl;
             }
