@@ -188,6 +188,7 @@ PanelView::PanelView(Plasma::Containment *panel, int id, QWidget *parent)
       m_panelController(0),
       m_glowBar(0),
       m_mousePollTimer(0),
+      m_strutsTimer(0),
       m_timeLine(0),
       m_spacer(0),
       m_spacerIndex(-1),
@@ -247,6 +248,10 @@ PanelView::PanelView(Plasma::Containment *panel, int id, QWidget *parent)
     KWindowSystem::setOnAllDesktops(winId(), true);
 
     QTimer::singleShot(0, this, SLOT(init()));
+
+    m_strutsTimer = new QTimer(this);
+    m_strutsTimer->setSingleShot(true);
+    connect(m_strutsTimer,SIGNAL(timeout()),this,SLOT(updateStruts()));
 }
 
 PanelView::~PanelView()
@@ -535,7 +540,8 @@ void PanelView::updatePanelGeometry()
     if (geom == geometry()) {
         // our geometry is the same, but the panel moved around
         // so make sure our struts are still valid
-        updateStruts();
+        m_strutsTimer->stop();
+        m_strutsTimer->start(STRUTSTIMERDELAY);
     } else {
         setGeometry(geom);
     }
@@ -870,22 +876,47 @@ void PanelView::updateStruts()
                                              strut.bottom_width,
                                              strut.bottom_start,
                                              strut.bottom_end);
+  if (m_panelController) {
+        m_panelController->setLocation(containment()->location());
+
+        if (m_panelController->isVisible()) {
+            m_panelController->resize(m_panelController->sizeHint());
+            m_panelController->move(m_panelController->positionForPanelGeometry(geometry()));
+        }
+
+        foreach (PanelAppletOverlay *o, m_moveOverlays) {
+            o->syncOrientation();
+        }
+    }
 }
 
+/*
+// handy for debugging :)
+void PanelView::enterEvent(QEvent *event)
+{
+    if (containment()) {
+        kDebug() << sceneRect() << containment()->geometry();
+    }
+    Plasma::View::enterEvent(event);
+}
+*/
+
 void PanelView::moveEvent(QMoveEvent *event)
 {
     //kDebug();
-    QWidget::moveEvent(event);
-    updateStruts();
+    Plasma::View::moveEvent(event);
+    m_strutsTimer->stop();
+    m_strutsTimer->start(STRUTSTIMERDELAY);
     recreateUnhideTrigger();
 }
 
 void PanelView::resizeEvent(QResizeEvent *event)
 {
     //kDebug() << event->oldSize() << event->size();
-    QWidget::resizeEvent(event);
+    Plasma::View::resizeEvent(event);
     recreateUnhideTrigger();
-    updateStruts();
+    m_strutsTimer->stop();
+    m_strutsTimer->start(STRUTSTIMERDELAY);
 #ifdef Q_WS_WIN
     appBarPosChanged();
 #endif
